# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..specialized import BRAINSCut


def test_BRAINSCut_inputs():
    input_map = dict(
        NoTrainingVectorShuffling=dict(argstr="--NoTrainingVectorShuffling ",),
        applyModel=dict(argstr="--applyModel ",),
        args=dict(argstr="%s",),
        computeSSEOn=dict(argstr="--computeSSEOn ",),
        createVectors=dict(argstr="--createVectors ",),
        environ=dict(nohash=True, usedefault=True,),
        generateProbability=dict(argstr="--generateProbability ",),
        histogramEqualization=dict(argstr="--histogramEqualization ",),
        method=dict(argstr="--method %s",),
        modelConfigurationFilename=dict(
            argstr="--modelConfigurationFilename %s", extensions=None,
        ),
        modelFilename=dict(argstr="--modelFilename %s",),
        multiStructureThreshold=dict(argstr="--multiStructureThreshold ",),
        netConfiguration=dict(argstr="--netConfiguration %s", extensions=None,),
        numberOfTrees=dict(argstr="--numberOfTrees %d",),
        randomTreeDepth=dict(argstr="--randomTreeDepth %d",),
        trainModel=dict(argstr="--trainModel ",),
        trainModelStartIndex=dict(argstr="--trainModelStartIndex %d",),
        validate=dict(argstr="--validate ",),
        verbose=dict(argstr="--verbose %d",),
    )
    inputs = BRAINSCut.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BRAINSCut_outputs():
    output_map = dict()
    outputs = BRAINSCut.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..reconstruction import EstimateResponseSH


def test_EstimateResponseSH_inputs():
    input_map = dict(
        auto=dict(xor=["recursive"],),
        b0_thres=dict(usedefault=True,),
        fa_thresh=dict(usedefault=True,),
        in_bval=dict(extensions=None, mandatory=True,),
        in_bvec=dict(extensions=None, mandatory=True,),
        in_evals=dict(extensions=None, mandatory=True,),
        in_file=dict(extensions=None, mandatory=True,),
        in_mask=dict(extensions=None,),
        out_mask=dict(extensions=None, usedefault=True,),
        out_prefix=dict(),
        recursive=dict(xor=["auto"],),
        response=dict(extensions=None, usedefault=True,),
        roi_radius=dict(usedefault=True,),
    )
    inputs = EstimateResponseSH.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_EstimateResponseSH_outputs():
    output_map = dict(out_mask=dict(extensions=None,), response=dict(extensions=None,),)
    outputs = EstimateResponseSH.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..dti import XFibres5


def test_XFibres5_inputs():
    input_map = dict(
        all_ard=dict(argstr="--allard", xor=("no_ard", "all_ard"),),
        args=dict(argstr="%s",),
        burn_in=dict(argstr="--burnin=%d", usedefault=True,),
        burn_in_no_ard=dict(argstr="--burnin_noard=%d", usedefault=True,),
        bvals=dict(argstr="--bvals=%s", extensions=None, mandatory=True,),
        bvecs=dict(argstr="--bvecs=%s", extensions=None, mandatory=True,),
        cnlinear=dict(
            argstr="--cnonlinear", xor=("no_spat", "non_linear", "cnlinear"),
        ),
        dwi=dict(argstr="--data=%s", extensions=None, mandatory=True,),
        environ=dict(nohash=True, usedefault=True,),
        f0_ard=dict(argstr="--f0 --ardf0", xor=["f0_noard", "f0_ard", "all_ard"],),
        f0_noard=dict(argstr="--f0", xor=["f0_noard", "f0_ard"],),
        force_dir=dict(argstr="--forcedir", usedefault=True,),
        fudge=dict(argstr="--fudge=%d",),
        gradnonlin=dict(argstr="--gradnonlin=%s", extensions=None,),
        logdir=dict(argstr="--logdir=%s", usedefault=True,),
        mask=dict(argstr="--mask=%s", extensions=None, mandatory=True,),
        model=dict(argstr="--model=%d",),
        n_fibres=dict(argstr="--nfibres=%d", mandatory=True, usedefault=True,),
        n_jumps=dict(argstr="--njumps=%d", usedefault=True,),
        no_ard=dict(argstr="--noard", xor=("no_ard", "all_ard"),),
        no_spat=dict(argstr="--nospat", xor=("no_spat", "non_linear", "cnlinear"),),
        non_linear=dict(
            argstr="--nonlinear", xor=("no_spat", "non_linear", "cnlinear"),
        ),
        output_type=dict(),
        rician=dict(argstr="--rician",),
        sample_every=dict(argstr="--sampleevery=%d", usedefault=True,),
        seed=dict(argstr="--seed=%d",),
        update_proposal_every=dict(argstr="--updateproposalevery=%d", usedefault=True,),
    )
    inputs = XFibres5.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_XFibres5_outputs():
    output_map = dict(
        dyads=dict(),
        fsamples=dict(),
        mean_S0samples=dict(extensions=None,),
        mean_dsamples=dict(extensions=None,),
        mean_fsamples=dict(),
        mean_tausamples=dict(extensions=None,),
        phsamples=dict(),
        thsamples=dict(),
    )
    outputs = XFibres5.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..calib import SFLUTGen


def test_SFLUTGen_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        binincsize=dict(argstr="-binincsize %d", units="NA",),
        directmap=dict(argstr="-directmap",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="-inputfile %s", extensions=None, mandatory=True,),
        info_file=dict(argstr="-infofile %s", extensions=None, mandatory=True,),
        minvectsperbin=dict(argstr="-minvectsperbin %d", units="NA",),
        order=dict(argstr="-order %d", units="NA",),
        out_file=dict(argstr="> %s", extensions=None, genfile=True, position=-1,),
        outputstem=dict(argstr="-outputstem %s", usedefault=True,),
        pdf=dict(argstr="-pdf %s", usedefault=True,),
    )
    inputs = SFLUTGen.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_SFLUTGen_outputs():
    output_map = dict(
        lut_one_fibre=dict(extensions=None,), lut_two_fibres=dict(extensions=None,),
    )
    outputs = SFLUTGen.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import CALabel


def test_CALabel_inputs():
    input_map = dict(
        align=dict(argstr="-align",),
        args=dict(argstr="%s",),
        aseg=dict(argstr="-aseg %s", extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=-4,),
        in_vol=dict(argstr="-r %s", extensions=None,),
        intensities=dict(argstr="-r %s", extensions=None,),
        label=dict(argstr="-l %s", extensions=None,),
        no_big_ventricles=dict(argstr="-nobigventricles",),
        num_threads=dict(),
        out_file=dict(argstr="%s", extensions=None, mandatory=True, position=-1,),
        prior=dict(argstr="-prior %.1f",),
        relabel_unlikely=dict(argstr="-relabel_unlikely %d %.1f",),
        subjects_dir=dict(),
        template=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        transform=dict(argstr="%s", extensions=None, mandatory=True, position=-3,),
    )
    inputs = CALabel.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_CALabel_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = CALabel.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..label_fusion import LabelFusion


def test_LabelFusion_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        classifier_type=dict(argstr="-%s", mandatory=True, position=2,),
        conv=dict(argstr="-conv %f",),
        dilation_roi=dict(),
        environ=dict(nohash=True, usedefault=True,),
        file_to_seg=dict(extensions=None, mandatory=True,),
        in_file=dict(argstr="-in %s", extensions=None, mandatory=True, position=1,),
        kernel_size=dict(),
        mask_file=dict(argstr="-mask %s", extensions=None,),
        max_iter=dict(argstr="-max_iter %d",),
        mrf_value=dict(argstr="-MRF_beta %f",),
        out_file=dict(
            argstr="-out %s",
            extensions=None,
            name_source=["in_file"],
            name_template="%s",
        ),
        prob_flag=dict(argstr="-outProb",),
        prob_update_flag=dict(argstr="-prop_update",),
        proportion=dict(argstr="-prop %s",),
        set_pq=dict(argstr="-setPQ %f %f",),
        sm_ranking=dict(argstr="-%s", position=3, usedefault=True,),
        template_file=dict(extensions=None,),
        template_num=dict(),
        unc=dict(argstr="-unc",),
        unc_thresh=dict(argstr="-uncthres %f",),
        verbose=dict(argstr="-v %s",),
    )
    inputs = LabelFusion.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_LabelFusion_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = LabelFusion.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..dti import DTLUTGen


def test_DTLUTGen_inputs():
    input_map = dict(
        acg=dict(argstr="-acg",),
        args=dict(argstr="%s",),
        bingham=dict(argstr="-bingham",),
        environ=dict(nohash=True, usedefault=True,),
        frange=dict(argstr="-frange %s", position=1, units="NA",),
        inversion=dict(argstr="-inversion %d", units="NA",),
        lrange=dict(argstr="-lrange %s", position=1, units="NA",),
        out_file=dict(argstr="> %s", extensions=None, genfile=True, position=-1,),
        samples=dict(argstr="-samples %d", units="NA",),
        scheme_file=dict(
            argstr="-schemefile %s", extensions=None, mandatory=True, position=2,
        ),
        snr=dict(argstr="-snr %f", units="NA",),
        step=dict(argstr="-step %f", units="NA",),
        trace=dict(argstr="-trace %G", units="NA",),
        watson=dict(argstr="-watson",),
    )
    inputs = DTLUTGen.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_DTLUTGen_outputs():
    output_map = dict(dtLUT=dict(extensions=None,),)
    outputs = DTLUTGen.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..qt1 import FitQt1


def test_FitQt1_inputs():
    input_map = dict(
        acceptance=dict(argstr="-acceptance %f",),
        args=dict(argstr="%s",),
        b1map=dict(argstr="-b1map %s", extensions=None,),
        comp_file=dict(
            argstr="-comp %s",
            extensions=None,
            name_source=["source_file"],
            name_template="%s_comp.nii.gz",
        ),
        environ=dict(nohash=True, usedefault=True,),
        error_file=dict(
            argstr="-error %s",
            extensions=None,
            name_source=["source_file"],
            name_template="%s_error.nii.gz",
        ),
        flips=dict(argstr="-flips %s", sep=" ",),
        flips_list=dict(argstr="-fliplist %s", extensions=None,),
        gn_flag=dict(argstr="-gn", position=8,),
        ir_flag=dict(argstr="-IR", position=13,),
        lm_val=dict(argstr="-lm %f %f", position=7,),
        m0map_file=dict(
            argstr="-m0map %s",
            extensions=None,
            name_source=["source_file"],
            name_template="%s_m0map.nii.gz",
        ),
        mask=dict(argstr="-mask %s", extensions=None, position=2,),
        maxit=dict(argstr="-maxit %d", position=11,),
        mcmap_file=dict(
            argstr="-mcmap %s",
            extensions=None,
            name_source=["source_file"],
            name_template="%s_mcmap.nii.gz",
        ),
        mcmaxit=dict(argstr="-mcmaxit %d",),
        mcout=dict(argstr="-mcout %s", extensions=None,),
        mcsamples=dict(argstr="-mcsamples %d",),
        nb_comp=dict(argstr="-nc %d", position=6,),
        prior=dict(argstr="-prior %s", extensions=None, position=3,),
        res_file=dict(
            argstr="-res %s",
            extensions=None,
            name_source=["source_file"],
            name_template="%s_res.nii.gz",
        ),
        slice_no=dict(argstr="-slice %d", position=9,),
        source_file=dict(
            argstr="-source %s", extensions=None, mandatory=True, position=1,
        ),
        spgr=dict(argstr="-SPGR",),
        sr_flag=dict(argstr="-SR", position=12,),
        syn_file=dict(
            argstr="-syn %s",
            extensions=None,
            name_source=["source_file"],
            name_template="%s_syn.nii.gz",
        ),
        t1_list=dict(argstr="-T1list %s", extensions=None,),
        t1map_file=dict(
            argstr="-t1map %s",
            extensions=None,
            name_source=["source_file"],
            name_template="%s_t1map.nii.gz",
        ),
        t1max=dict(argstr="-T1max %f",),
        t1min=dict(argstr="-T1min %f",),
        te_value=dict(argstr="-TE %f", position=4,),
        tis=dict(argstr="-TIs %s", position=14, sep=" ",),
        tis_list=dict(argstr="-TIlist %s", extensions=None,),
        tr_value=dict(argstr="-TR %f", position=5,),
        voxel=dict(argstr="-voxel %d %d %d", position=10,),
    )
    inputs = FitQt1.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_FitQt1_outputs():
    output_map = dict(
        comp_file=dict(extensions=None,),
        error_file=dict(extensions=None,),
        m0map_file=dict(extensions=None,),
        mcmap_file=dict(extensions=None,),
        res_file=dict(extensions=None,),
        syn_file=dict(extensions=None,),
        t1map_file=dict(extensions=None,),
    )
    outputs = FitQt1.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import ReHo


def test_ReHo_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        chi_sq=dict(argstr="-chi_sq",),
        ellipsoid=dict(
            argstr="-neigh_X %s -neigh_Y %s -neigh_Z %s",
            xor=["sphere", "neighborhood"],
        ),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="-inset %s", extensions=None, mandatory=True, position=1,),
        label_set=dict(argstr="-in_rois %s", extensions=None,),
        mask_file=dict(argstr="-mask %s", extensions=None,),
        neighborhood=dict(argstr="-nneigh %s", xor=["sphere", "ellipsoid"],),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            keep_extension=True,
            name_source="in_file",
            name_template="%s_reho",
            position=0,
        ),
        overwrite=dict(argstr="-overwrite",),
        sphere=dict(argstr="-neigh_RAD %s", xor=["neighborhood", "ellipsoid"],),
    )
    inputs = ReHo.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ReHo_outputs():
    output_map = dict(out_file=dict(extensions=None,), out_vals=dict(extensions=None,),)
    outputs = ReHo.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..registration import CompositeTransformUtil


def test_CompositeTransformUtil_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s...", mandatory=True, position=3,),
        num_threads=dict(nohash=True, usedefault=True,),
        out_file=dict(argstr="%s", extensions=None, position=2,),
        output_prefix=dict(argstr="%s", position=4, usedefault=True,),
        process=dict(argstr="--%s", position=1, usedefault=True,),
    )
    inputs = CompositeTransformUtil.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_CompositeTransformUtil_outputs():
    output_map = dict(
        affine_transform=dict(extensions=None,),
        displacement_field=dict(extensions=None,),
        out_file=dict(extensions=None,),
    )
    outputs = CompositeTransformUtil.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import Overlay


def test_Overlay_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        auto_thresh_bg=dict(
            argstr="-a",
            mandatory=True,
            position=5,
            xor=("auto_thresh_bg", "full_bg_range", "bg_thresh"),
        ),
        background_image=dict(
            argstr="%s", extensions=None, mandatory=True, position=4,
        ),
        bg_thresh=dict(
            argstr="%.3f %.3f",
            mandatory=True,
            position=5,
            xor=("auto_thresh_bg", "full_bg_range", "bg_thresh"),
        ),
        environ=dict(nohash=True, usedefault=True,),
        full_bg_range=dict(
            argstr="-A",
            mandatory=True,
            position=5,
            xor=("auto_thresh_bg", "full_bg_range", "bg_thresh"),
        ),
        out_file=dict(
            argstr="%s", extensions=None, genfile=True, hash_files=False, position=-1,
        ),
        out_type=dict(argstr="%s", position=2, usedefault=True,),
        output_type=dict(),
        show_negative_stats=dict(argstr="%s", position=8, xor=["stat_image2"],),
        stat_image=dict(argstr="%s", extensions=None, mandatory=True, position=6,),
        stat_image2=dict(
            argstr="%s", extensions=None, position=9, xor=["show_negative_stats"],
        ),
        stat_thresh=dict(argstr="%.2f %.2f", mandatory=True, position=7,),
        stat_thresh2=dict(argstr="%.2f %.2f", position=10,),
        transparency=dict(argstr="%s", position=1, usedefault=True,),
        use_checkerboard=dict(argstr="-c", position=3,),
    )
    inputs = Overlay.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Overlay_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = Overlay.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..base import WatershedBEM


def test_WatershedBEM_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        atlas_mode=dict(argstr="--atlas",),
        environ=dict(nohash=True, usedefault=True,),
        overwrite=dict(argstr="--overwrite", usedefault=True,),
        subject_id=dict(argstr="--subject %s", mandatory=True,),
        subjects_dir=dict(mandatory=True, usedefault=True,),
        volume=dict(argstr="--volume %s", usedefault=True,),
    )
    inputs = WatershedBEM.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_WatershedBEM_outputs():
    output_map = dict(
        brain_surface=dict(extensions=None, loc="bem/watershed",),
        cor_files=dict(altkey="COR", loc="bem/watershed/ws",),
        fif_file=dict(altkey="fif", extensions=None, loc="bem",),
        inner_skull_surface=dict(extensions=None, loc="bem/watershed",),
        mesh_files=dict(),
        outer_skin_surface=dict(extensions=None, loc="bem/watershed",),
        outer_skull_surface=dict(extensions=None, loc="bem/watershed",),
    )
    outputs = WatershedBEM.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value
